import React, { useContext } from 'react';
import { Space, Popover } from 'antd';
import {
  MenuUnfoldOutlined,
  RedoOutlined
} from '@ant-design/icons'
import classnames from 'classnames';
import TableContext from '../context';
import ColumnSetting from './ColumnSetting';
import './index.less';

interface OptionsProps {
  refresh?: boolean;
  columnSetting?: boolean;
}

export interface ToolbarProps {
  className?: string;
  style?: React.CSSProperties;
  actions?: React.ReactNode[];
  options?: OptionsProps;
  slot?: React.ReactNode[];
}

const Toolbar: React.FC<ToolbarProps> = ({
  className,
  style,
  actions,
  options = {},
  slot,
}) => {
  const { refresh = false, columnSetting = false } = options;
  const { fetchData } = useContext(TableContext);

  const showOptionsBar = Object.values(options).some(item => item);

  return (
    <div
      className={classnames('uniubi-pro-table-toolbar', className)}
      style={style}
    >
      <div className={'uniubi-pro-table-toolbar-side-left'}>
        {actions && (
          <Space className={'uniubi-pro-table-toolbar-actions'}>
            {actions}
          </Space>
        )}
      </div>
      <div className={'uniubi-pro-table-toolbar-side-right'}>
        {slot && (
          <Space className={'uniubi-pro-table-toolbar-slot'}>{slot}</Space>
        )}
        {showOptionsBar && (
          <Space className={'uniubi-pro-table-toolbar-options'} size={12}>
            {refresh && <RedoOutlined onClick={fetchData} />}
            {columnSetting && (
              <Popover
                overlayClassName={
                  'uniubi-pro-table-toolbar-options-setting-popover'
                }
                content={<ColumnSetting />}
                trigger="click"
                placement="bottomRight"
              >
                <MenuUnfoldOutlined />
              </Popover>
            )}
          </Space>
        )}
      </div>
    </div>
  );
};

export default Toolbar;
